#
# spec file for package wardstone
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           wardstone
#               This will be set by osc services, that will run after this.
Version:        0.2.0~0
Release:        2.4
Summary:        Assess compliance for cryptographic keys
License:        ISC
#               Select a group from this link:
#               https://en.opensuse.org/openSUSE:Package_group_guidelines
Group:          Productivity/Security
URL:            https://github.com/openSUSE/wardstone
Source0:        %{name}-%{version}.tar.zst
Source1:        vendor.tar.zst
Source2:        cargo_config
BuildRequires:  cargo-packaging >= 1.2.0
BuildRequires:  openssl-devel

%description
The wardstone project aims to create a library that can be used across different programming languages via a foreign function interface and a command line utility that users can run against their existing keys to detect conformance to varying cryptographic key standards and research publications.

%package        devel
Summary:        FFI bindings for wardstone
Group:          Productivity/Security

%description    devel
A version of wardstone_core that exports a foreign function interface for using the library from C and other languages that support it.

%prep
%autosetup -a1
install -D -m 644 %{SOURCE2} .cargo/config

%build
%{cargo_build} --all

%install
# CLI program
%{cargo_install -p crates/cmd}

# FFI devel
install -D -d -m 0755 %{buildroot}%{_libdir}
install -m 0755 %{_builddir}/%{name}-%{version}/target/release/libwardstone.so %{buildroot}%{_libdir}/libwardstone.so
install -D -d -m 0755 %{buildroot}%{_includedir}
install -m 0644 %{_builddir}/%{name}-%{version}/target/wardstone.h %{buildroot}%{_includedir}/wardstone.h

%check
%{cargo_test}

%files
%{_bindir}/%{name}

%files devel
%{_includedir}/wardstone.h
%{_libdir}/libwardstone.so

%changelog
* Fri Nov  8 2024 Dennis Knorr <dennis.knorr@suse.com>
- updating github links
- updating cargo dependencies to fix the build
* Tue Oct 24 2023 Martin Sirringhaus <martin.sirringhaus@suse.com>
- Update to 0.2.0
  * feat: enable user set context
    The caller can now set the context year that they want
    to assess a cryptographic primitive to be assessed against.
    This allows them to override the default option which is
    current based on the year 2023 with an average horizon of
    about 4 to 8 years.
  * refactor: update elliptic curve display strings
    Some primitives do not have a unique name which may
    make it difficult to someone unfamiliar with the
    distinctions to interpret the results of an audit. The
    output for these primitives now mentions all known names
    so that the user does not have to access a secondary
    source for this information.
  * refactor: update the name of the library
    Object libraries generated no longer have a _ffi prefix.
* Sun Aug 20 2023 Martin Sirringhaus <martin.sirringhaus@suse.com>
- Initial commit of wardstone
  * use an older C compiler standard
  * add cbindgen
  * create basic CI workflow
  * fix syntax errors and avoid running on push
  * remove nightly rustfmt config options
  * update cbindgen configuration
  * create issue templates
  * update build script
  * recommend alternatives for invalid primitives
  * add check for documentation
  * add FFI-compiling to CI
  * minor cosmetic changes to CI
  * add finite field cryptography primitives
  * add integer factorisation primitives
  * add elliptic-curve cryptography primitives
  * add the SHAKE extendable-output functions
  * update build script
  * add more crate types
  * complete NIST Special Publication 800-57 Part 1 Revision 5 module
  * factor in context security and update ranges in NIST module
  * add SHAKE XOFs
  * create BSI TR-02102-1 Cryptographic Mechanisms: Recommendations and Key Lengths module
  * create CNSA module
  * create ECRYPT module
  * complete Lenstra module
  * split the crate into two
  * implement interfaces custom standards
  * update example in wardstone_core README
  * create mock standards
  * allow use of NIST curves in the BSI guide
  * create wardstone command line program
  * add some polish around validating elliptic curve signed certificates in the command-line application
  * remove references
  * update documentation
  * decode primitives using their ASN1 encoding
  * add more OID to primitive mappings in the table
  * update OIDs
  * support RSA PSS keys
  * update documentation
  * commit Cargo lock file for OBS builds
  * note openssl-dev requirement
  * support auditing SSH keys
  * handle multiple files as input, and support optional JSON-format when reporting
  * update handling multiple files
